@@ -60,7 +60,11 @@ def command():
     "-u",
     "--url",
     envvar="TUTOR_XQUEUE_URL",
-    help="Xqueue server base url. By default, this value will be defined from the plugin configuration. Alternatively, this value can be defined from the TUTOR_XQUEUE_URL environment variable.",
+    help=(
+        "Xqueue server base url. By default, this value will be defined from "
+        "the plugin configuration. Alternatively, this value can be defined "
+        "from the TUTOR_XQUEUE_URL environment variable."
+    ),
 )
 def submissions(context, queue, url):
     context.queue = queue
@@ -153,10 +157,17 @@ class Client:
         submission_body = json.loads(data["xqueue_body"])
         submission_id = header["submission_id"]
         submission_key = header["submission_key"]
+        submission_files = {}
+        for filename, path in json.loads(data["xqueue_files"]).items():
+            if not path.startswith("http"):
+                # Relative path: prepend with server url
+                path = self.base_url + "/" + path
+            submission_files[filename] = path
         return {
             "id": submission_id,
             "key": submission_key,
             "body": submission_body,
+            "files": submission_files,
             "return_code": response["return_code"],
         }
 
